#############################################################################
##
#W  fpcomsmg.gd           GAP library         Isabel Araujo and Andrew Solomon
##
#H  @(#)$Id: fpcomsmg.gd,v 1.1 1999/04/28 17:34:09 andrews Exp $
##
#Y  Copyright (C)  1997,  Lehrstuhl D fuer Mathematik,  RWTH Aachen,  Germany
#Y  (C) 1998 School Math and Comp. Sci., University of St.  Andrews, Scotland
##
##  
##

Revision.fpcomsmg_gd :=
    "@(#)$Id: fpcomsmg.gd,v 1.1 1999/04/28 17:34:09 andrews Exp $";


############################################################################
##
#F  AssocWordToVector(<w>)
##  
##	for an associative word <w>. 
##	Returns the vector of exponents of each generator in <word>.
##
DeclareGlobalFunction("AssocWordToVector");

############################################################################
##
#F  ElementOfFpSemigroupAsVector(<e>)
##  
##	for an element <e> of a finitely presented semigroup. 
##	Returns the vector of exponents of the underlying word.
##
DeclareGlobalFunction("ElementOfFpSemigroupAsVector");

############################################################################
##
#F  VectorToElementOfCommutativeFpSemigroup(<S>,<v>)
##  
##	for a commutative semigroup <S> and a vector <v>. Returns the
##	element of <S> which has as underlying word the product
##	of the free generators with the exponents the entries of the vector.
##
DeclareGlobalFunction("VectorToElementOfCommutativeFpSemigroup");

############################################################################
##
#F  SizeOfFpCommutativeSemigroup(<S>)
##  
##	for a finitely presented commutative semigroup <S>.
##
DeclareGlobalFunction("SizeOfFpCommutativeSemigroup");

#############################################################################
##
#M  EpimorphismAbelianization(<S>)
##
##  returns an epimorphism from an fp semigroup to its abelianization.
##
DeclareAttribute("EpimorphismAbelianization", IsFpSemigroup);

#############################################################################
##
#A  Abelianization(<S>)
##
##	returns the abelianization of the finitely presented semigroup <S>.
##
DeclareAttribute("Abelianization", IsFpSemigroup);

############################################################################
##
#F  VectorOfSupOfEntriesOfElementsOfCommutativeFpSemigroup(<S>) 
##
##  for a commutative finitely presented semigroup <S> and a vector <v>.
##  Returns fail if the semigroup is infinite. Otherwise returns a
##  vector, each entry of which is the minimum exponent to
##  which the corresponding generator has to be raised to get a non-reduced
##  word.
##  Note that, when <S> is finite, this gives an upper
##  bound for the number of elements of <S> (since any element
##  of <S> is represented by a reduced word and any reduced word has
##  to be represented as a vector with entries less than the ones
##  of the vector returned by this function).
##
DeclareGlobalFunction("VectorOfSupOfEntriesOfElementsOfCommutativeFpSemigroup");

############################################################################
##
#F  ReducedSetOfGeneratorsOfPrincipalIdealOfSemigroup( <S> , <e> )
##
##	for a commutative finitely presented semigroup <S> and an element
##	of the semigroup.
##	It returns the subset of reduced words of the set of minimal
##	generators of the ideal of the words representing elements
##	in the principal ideal of <S> generated by <e>.
##	Notice that this is a decision procedure to decide whether a given
##	word represents an element of the principal ideal of <S> generated by <e>.
##
DeclareGlobalFunction("ReducedSetOfGeneratorsOfPrincipalIdealOfSemigroup");

#############################################################################
##
#E  commsmg.gd  . . . . . . . . . . . . . . . . . . . . . . . . . . ends here
